/* -*- c++ -*- */
/*
 * Copyright 2016 The Aerospace Corporation.
 *
 * This is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3, or (at your option)
 * any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this software; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street,
 * Boston, MA 02110-1301, USA.
 */


#ifndef INCLUDED_GOESSDR_GOES_SINK_H
#define INCLUDED_GOESSDR_GOES_SINK_H

#include <goessdr/api.h>

#include <gnuradio/sync_block.h>
#include <gnuradio/blocks/delay.h>

namespace gr {
  namespace goessdr {

    /*!
     * \brief Decodes and outputs LRIT files.
     * \ingroup goessdr
     *
     */
    class GOESSDR_API goes_sink : virtual public gr::sync_block
    {
    public:
      typedef boost::shared_ptr<goes_sink> sptr;

      static sptr make(int resynch_thresh,            // # of bit errors in sync word (out of 32) before declaring unsync'd after sync
                       int delay_thresh,              // # of bad packets before toggling delay
                       const std::string &lritdir,    // LRIT products output directory
                       const std::string &emwindir    // EMWIN products output directory
                      );
      virtual void reset_error_counts(const pmt::pmt_t &msg) = 0;     // reset error counts
      virtual void report_error_counts(const pmt::pmt_t &msg) = 0;    // reset error counts
      virtual void set_output_dirs(const std::string &ldir,
                                   const std::string &edir) = 0;      // set output directories
    };

  } // namespace goes
} // namespace gr

#endif /* INCLUDED_GOESSDR_GOES_SINK_H */

