/* -*- c++ -*- */
/*
 * Copyright 2016 The Aerospace Corporation.
 *
 * This is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3, or (at your option)
 * any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this software; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street,
 * Boston, MA 02110-1301, USA.
 */

#ifndef INCLUDED_GOESSDR_GOES_SINK_IMPL_H
#define INCLUDED_GOESSDR_GOES_SINK_IMPL_H

#include "goessdr/goes_sink.h"
#include "GoesProcessor.h"

namespace gr {
  namespace goessdr {

    class goes_sink_impl : public goes_sink
    {
      /*!
       * \brief Write stream to file.
       * \ingroup sink
       */
    private:
      CGoesProcessor  d_lrit_processor;
      int             d_resynch_thresh;
      bool            d_synched;
      bool            d_delayed;
      bool            d_rotated;

      void toggle_viterbi_delay();
      void toggle_rotate();

    public:
      goes_sink_impl(int resynch_thresh, int delay_thresh,
                     const std::string &lritdir, const std::string &emwindir);
      ~goes_sink_impl();

      bool get_synch();

      int work(int noutput_items,
	       gr_vector_const_void_star &input_items,
	       gr_vector_void_star &output_items);

      void reset_error_counts(const pmt::pmt_t &msg);
      void report_error_counts(const pmt::pmt_t &msg);
      void set_output_dirs(const std::string &ldir, const std::string &edir);
    };

  } // namespace goessdr
} // namespace gr

#endif /* INCLUDED_GOESSDR_GOES_SINK_IMPL_H */

